==> CDTCloudBlueprint-1.24.0-mac.zip: CDTCloudBlueprint.app/Contents/Resources/app/plugins/vscode-cmake/extension/README.md <==
# CMake Tools

[CMake Tools](https://marketplace.visualstudio.com/items?itemName=ms-vscode.cmake-tools) provides the native developer a full-featured, convenient, and powerful workflow for CMake-based projects in Visual Studio Code.

## Important doc links

- [CMake Tools quick start](https://code.visualstudio.com/docs/cpp/CMake-linux)
- [Configure and build a project with CMake Presets](https://github.com/microsoft/vscode-cmake-tools/blob/HEAD/docs/cmake-presets.md)
- [Configure a project with kits and variants](https://github.com/microsoft/vscode-cmake-tools/blob/HEAD/docs/how-to.md#configure-a-project)
- [Build a project with kits and variants](https://github.com/microsoft/vscode-cmake-tools/blob/HEAD/docs/how-to.md#build-a-project)
- [Debug a project](https://github.com/microsoft/vscode-cmake-tools/blob/HEAD/docs/how-to.md#debug-a-project)
- [Configure CMake Tools settings](https://github.com/microsoft/vscode-cmake-tools/blob/HEAD/docs/cmake-settings.md)
- [How to](https://github.com/microsoft/vscode-cmake-tools/blob/HEAD/docs/how-to.md)
- [FAQ](https://github.com/microsoft/vscode-cmake-tools/blob/HEAD/docs/faq.md)
- [Read the online documentation](https://github.com/microsoft/vscode-cmake-tools/blob/HEAD/docs/README.md)
- [Contribute](https://github.com/microsoft/vscode-cmake-tools/blob/HEAD/CONTRIBUTING.md)

## Issues? Questions? Feature requests?

**PLEASE**, if you experience any problems, have any questions, or have an idea
for a new feature, create an issue on [the GitHub page](https://github.com/microsoft/vscode-cmake-tools)!

This extension itself *does not* provide language support for the CMake
scripting language. For that we recommend [this extension](https://marketplace.visualstudio.com/items?itemName=twxs.cmake).

### Microsoft Open Source Code of Conduct

This project has adopted the [Microsoft Open Source Code of Conduct](https://opensource.microsoft.com/codeofconduct/). For more information see the [Code of Conduct FAQ](https://opensource.microsoft.com/codeofconduct/faq/) or contact opencode@microsoft.com with any additional questions or comments.

### Data/Telemetry

This extension collects usage data and sends it to Microsoft to help improve our products and services. Collection of telemetry is controlled via the same setting provided by Visual Studio Code: `"telemetry.enableTelemetry"`. Read our [privacy statement](https://privacy.microsoft.com/en-us/privacystatement) to learn more.

### Credits

This project was started by [@vector-of-bool](https://github.com/vector-of-bool) and is now currently maintained by Microsoft.

==> CDTCloudBlueprint-1.55.0-mac.zip: CDTCloudBlueprint.app/Contents/Resources/app/plugins/vscode-cmake/extension/README.md <==
# CMake Tools

[CMake Tools](https://marketplace.visualstudio.com/items?itemName=ms-vscode.cmake-tools) provides the native developer a full-featured, convenient, and powerful workflow for CMake-based projects in Visual Studio Code.

## Important doc links

- [CMake Tools quick start](https://code.visualstudio.com/docs/cpp/CMake-linux)
- [Configure and build a project with CMake Presets](https://github.com/microsoft/vscode-cmake-tools/blob/HEAD/docs/cmake-presets.md)
- [Configure a project with kits and variants](https://github.com/microsoft/vscode-cmake-tools/blob/HEAD/docs/how-to.md#configure-a-project)
- [Build a project with kits and variants](https://github.com/microsoft/vscode-cmake-tools/blob/HEAD/docs/how-to.md#build-a-project)
- [Configure and build a project using tasks](https://github.com/microsoft/vscode-cmake-tools/blob/HEAD/docs/tasks.md)
- [Debug a project](https://github.com/microsoft/vscode-cmake-tools/blob/HEAD/docs/how-to.md#debug-a-project)
- [Configure CMake Tools settings](https://github.com/microsoft/vscode-cmake-tools/blob/HEAD/docs/cmake-settings.md)
- [How to](https://github.com/microsoft/vscode-cmake-tools/blob/HEAD/docs/how-to.md)
- [FAQ](https://github.com/microsoft/vscode-cmake-tools/blob/HEAD/docs/faq.md)
- [Read the online documentation](https://github.com/microsoft/vscode-cmake-tools/blob/HEAD/docs/README.md)
- [Contribute](https://github.com/microsoft/vscode-cmake-tools/blob/HEAD/CONTRIBUTING.md)

## Issues? Questions? Feature requests?

**PLEASE**, if you experience any problems, have any questions, or have an idea
for a new feature, create an issue on [the GitHub page](https://github.com/microsoft/vscode-cmake-tools)!

This extension itself *does not* provide language support for the CMake scripting language.
For that we bundle [this extension](https://marketplace.visualstudio.com/items?itemName=twxs.cmake) which provides the support.
A closed-source extension that provides even better support can also be installed: [CMake Language Support](https://marketplace.visualstudio.com/items?itemName=josetr.cmake-language-support-vscode)

### Microsoft Open Source Code of Conduct

This project has adopted the [Microsoft Open Source Code of Conduct](https://opensource.microsoft.com/codeofconduct/). For more information see the [Code of Conduct FAQ](https://opensource.microsoft.com/codeofconduct/faq/) or contact opencode@microsoft.com with any additional questions or comments.

### Data/Telemetry

This extension collects usage data and sends it to Microsoft to help improve our products and services. Collection of telemetry is controlled via the same setting provided by Visual Studio Code: `"telemetry.enableTelemetry"`. Read our [privacy statement](https://privacy.microsoft.com/en-us/privacystatement) to learn more.

### Credits

This project was started by [@vector-of-bool](https://github.com/vector-of-bool) and is now currently maintained by Microsoft.
